package cn.com.ty.lift.enterprise.custom.controller;

import cn.com.ty.lift.enterprise.custom.dao.entity.PropertyCompany;
import cn.com.ty.lift.enterprise.custom.dao.entity.model.PropertyCompanyReq;
import cn.com.ty.lift.enterprise.custom.service.impl.PropertyCompanyServiceImpl;
import cn.com.xwy.boot.web.dto.RestResponse;
import lombok.AllArgsConstructor;
import org.springframework.web.bind.annotation.*;

@RestController
@RequestMapping("/property-company")
@AllArgsConstructor
/**
 * @author wang-hai-cheng
 * @date 2019/11/27
 * @description
 * 客户接口(物业公司)(甲方公司) 前端控制器
 */
public class PropertyCompanyController {
    private final PropertyCompanyServiceImpl propertyCompanyService;

    @GetMapping("/{id}")
    /**
     * @description 根据id获取客户详细信息
     * @date 2019/11/27 11:36
     * @param [客户id]
     * @return cn.com.xwy.boot.web.dto.RestResponse
     */
    public RestResponse propertyCompany(@PathVariable Long id) {
        PropertyCompany byId = propertyCompanyService.getById(id);
        if (byId != null) {
            return RestResponse.ok(byId, "1", "查询成功");
        } else {
            return RestResponse.ok(null, "0", "无数据");
        }
    }

    @PostMapping("/list/condition")
    /**
     * @description 根据条件查询客户列表
     * @date 2019/12/3 8:51
     * @param [客户名称或客户地址或客户联系方式,页码,页大小,维保公司id]
     * @return cn.com.xwy.boot.web.dto.RestResponse
     */
    public RestResponse propertyCompaniesForCondition(@RequestBody PropertyCompanyReq propertyCompany) {
        return propertyCompanyService.propertyCompaniesForCondition(propertyCompany);
    }


    @PostMapping("/add")
    /**
     * @description 新增客户
     * @date 2019/11/27 11:45
     * @param [客户]
     * @return cn.com.xwy.boot.web.dto.RestResponse
     */
    public RestResponse add(@RequestBody PropertyCompany propertyCompany) {
        //service层判断了是否有相同名称的name
        return propertyCompanyService.savePropertyCompany(propertyCompany);
    }

    @PostMapping("/update")
    /**
     * @description 更新客户信息
     * @date 2019/11/27 11:45
     * @param [客户]
     * @return cn.com.xwy.boot.web.dto.RestResponse
     */
    public RestResponse update(@RequestBody PropertyCompany propertyCompany) {
        if (propertyCompanyService.updateById(propertyCompany)) {
            return RestResponse.ok(null, "1", "更新成功");
        } else {
            return RestResponse.ok(null, "0", "更新失败");
        }
    }

    @PostMapping("/delete")
    /**
     * @description RestResponse
     * @date 2019/11/27 11:46
     * @param [id]
     * @return cn.com.xwy.boot.web.dto.RestResponse
     */
    public RestResponse delete(@RequestBody PropertyCompany propertyCompany) {

        //判断维保电梯台数是否为0
        //判断维保电梯台数是否为0
        //判断维保电梯台数是否为0
        //判断维保电梯台数是否为0
        //判断维保电梯台数是否为0
        //判断维保电梯台数是否为0
        //判断维保电梯台数是否为0
        //判断维保电梯台数是否为0
        //判断维保电梯台数是否为0
        //判断维保电梯台数是否为0
        //判断维保电梯台数是否为0
        //也就是客户公司创建的所有项目的总电梯的在保电梯是否为0

        return RestResponse.ok(null, propertyCompanyService.delete(propertyCompany.getId()));
    }

    @GetMapping("/list/current")
    public RestResponse currentProject(@RequestBody PropertyCompany propertyCompany) {
        propertyCompany.getId();
        //分页查询正在服务的项目列表
        //分页查询正在服务的项目列表
        //分页查询正在服务的项目列表
        //分页查询正在服务的项目列表
        //分页查询正在服务的项目列表
        return RestResponse.ok(null, "待实现");
    }

    @GetMapping("/list/previous")
    public RestResponse previousProject(@RequestBody PropertyCompany propertyCompany) {
        propertyCompany.getId();
        //分页查询曾经服务的项目列表
        //分页查询曾经服务的项目列表
        //分页查询曾经服务的项目列表
        //分页查询曾经服务的项目列表
        //分页查询曾经服务的项目列表
        return RestResponse.ok(null, "待实现");
    }
}