package cn.com.ty.lift.enterprise.custom.controller;

import cn.com.ty.lift.enterprise.custom.dao.entity.PropertyContact;
import cn.com.ty.lift.enterprise.custom.dao.entity.model.PropertyContactReq;
import cn.com.ty.lift.enterprise.custom.service.impl.PropertyContactServiceImpl;
import cn.com.xwy.boot.web.dto.RestResponse;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.AllArgsConstructor;
import org.springframework.web.bind.annotation.*;

@RestController
@RequestMapping("/property-contact")
@AllArgsConstructor
/**
 * @author wang-hai-cheng
 * @date 2019/11/27
 * @description
 * (甲方联系人)客户联系人表 前端控制器
 */
public class PropertyContactController {
    private final PropertyContactServiceImpl propertyContactService;

    @GetMapping("/list")
    /**
     * @description 根据客户id分页查它的联系人
     * @date 2019/11/29 8:21
     * @param [ppCompanyId, userId, pageNum, pageSize]
     * @return cn.com.xwy.boot.web.dto.RestResponse
     */
    public RestResponse propertyContacts(@RequestBody PropertyContactReq propertyContact) {
        Page<PropertyContact> page = new Page<>(propertyContact.getPageNum(), propertyContact.getPageSize());
        IPage<PropertyContact> records = propertyContactService.page(page, new QueryWrapper<PropertyContact>()
                .select("id", "pp_company_id", "name", "dept", "job", "telephone", "gender", "age", "remarks", "status", "user_id")
                .eq("pp_company_id", propertyContact.getPpCompanyId())
                .eq("user_id", propertyContact.getUserId()));
        if (!records.getRecords().isEmpty()) {
            return RestResponse.ok(records, "1", "查询成功");
        } else {
            return RestResponse.ok(null, "9", "无数据");
        }
    }

    @PostMapping("/add")
    /**
     * @description 根据客户id，新增联系人
     * @date 2019/11/27 11:23
     * @param [propertyContact]
     * @return cn.com.xwy.boot.web.dto.RestResponse
     */
    public RestResponse add(@RequestBody PropertyContact propertyContact) {
        if (propertyContactService.save(propertyContact)) {
            return RestResponse.ok(null, "1", "新增成功");
        } else {
            return RestResponse.ok(null, "0", "新增失败");
        }
    }

    @PostMapping("/update")
    /**
     * @description 编辑联系人
     * @date 2019/11/27 11:26
     * @param [propertyContact]
     * @return cn.com.xwy.boot.web.dto.RestResponse
     */
    public RestResponse update(@RequestBody PropertyContact propertyContact) {
        if (propertyContactService.updateById(propertyContact)) {
            return RestResponse.ok(null, "1", "更新成功");
        } else {
            return RestResponse.ok(null, "0", "更新失败");
        }
    }

    @GetMapping("/delete")
    /**
     * @description 删除联系人
     * @date 2019/11/27 11:28
     * @param [id]
     * @return cn.com.xwy.boot.web.dto.RestResponse
     */
    public RestResponse delete(@RequestBody PropertyContact propertyContact) {
        return propertyContactService.delete(propertyContact.getId());
    }
}