package cn.com.ty.lift.system.faq.service.impl;

import cn.com.ty.lift.system.faq.entity.Faq;
import cn.com.ty.lift.system.faq.mapper.FaqMapper;
import cn.com.ty.lift.system.faq.service.FaqService;
import cn.com.xwy.boot.web.dto.RestResponse;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * <p>
 * 常见问题级常见问题分类表 服务实现类
 * </p>
 *
 * @author wang-hai-cheng
 * @since 2019-11-21
 */
@Transactional
@Service
@AllArgsConstructor
public class FaqServiceImpl extends ServiceImpl<FaqMapper, Faq> implements FaqService {

    public RestResponse addOne(String title, String description) {
        Faq faq = new Faq();
        faq.setContent(title).setType(1).setParentId(0).setDescription(description);
        faq.setSerial(this.count(new QueryWrapper<Faq>().eq("type", 1).eq("parent_id", 0)) + 1);
        if (this.save(faq)) {
            return RestResponse.ok(null, "1", "新增一级分类成功");
        } else {
            return RestResponse.ok(null, "0", "新增一级分类失败");
        }
    }

    public RestResponse addChild(int parentId, String title, String description) {
        Faq faq = new Faq();
        faq.setContent(title).setType(1).setParentId(parentId).setDescription(description);
        faq.setSerial(this.list(new QueryWrapper<Faq>().eq("type", 1).eq("parent_id", parentId)).size() + 1);
        if (this.save(faq)) {
            return RestResponse.ok(null, "1", "新增子分类成功");
        } else {
            return RestResponse.ok(null, "0", "新增子分类失败");
        }
    }

    public RestResponse addQuestion(int parentId, String title, String description) {
        Faq faq = new Faq();
        faq.setContent(title).setType(2).setParentId(parentId).setDescription(description);
        faq.setSerial(this.list(new QueryWrapper<Faq>().eq("type", 2).eq("parent_id", parentId)).size() + 1);
        if (this.save(faq)) {
            return RestResponse.ok(null, "1", "新增问题成功");
        } else {
            return RestResponse.ok(null, "0", "新增问题失败");
        }
    }

    public RestResponse addAnswer(int parentId, String content, String description) {
        Faq faq = new Faq();
        faq.setContent(content).setType(3).setParentId(parentId).setDescription(description);
        faq.setSerial(this.list(new QueryWrapper<Faq>().eq("type", 3).eq("parent_id", parentId)).size() + 1);
        if (this.save(faq)) {
            return RestResponse.ok(null, "1", "新增答案成功");
        } else {
            return RestResponse.ok(null, "0", "新增答案失败");
        }
    }

    public RestResponse up(int id, String title, String description) {
        Faq byId = this.getById(id);
        byId.setContent(title).setDescription(description);
        if (this.updateById(byId)) {
            return RestResponse.ok(null, "1", "更新成功");
        } else {
            return RestResponse.ok(null, "0", "更新失败");
        }
    }

    public RestResponse delete(int id) {
        if (deleteAll(id)) {
            return RestResponse.ok(null, "1", "删除成功");
        } else {
            return RestResponse.ok(null, "0", "删除失败");
        }
    }

    //递归删除id及它下面所有分类，问答
    private boolean deleteAll(int id) {
        //获取父id下的所有子分类或问答
        List<Faq> faqs = this.list(new QueryWrapper<Faq>().eq("parent_id", id));
        //删除父id下的所有子分类或问答
        this.remove(new QueryWrapper<Faq>().eq("parent_id", id));
        //删除自己
        this.remove(new QueryWrapper<Faq>().eq("id", id));
        //如果父id下还有子分类或问答
        if (faqs.size() != 0) {
            //遍历删除自己及删除自己下的所有子分类或问答
            faqs.forEach(faq -> {
                this.remove(new QueryWrapper<Faq>().eq("parent_id", id));
                this.remove(new QueryWrapper<Faq>().eq("id", id));
                //递归删除
                deleteAll(faq.getParentId());
            });
            //删除完毕返回true
            return true;
        } else {
            //如果没有子分类或问答就直接返回了
            return true;
        }
    }

    public RestResponse up(int id) {
        Faq up = this.getById(id);
        if (up != null) {
            if (up.getSerial() > 1) {
                Faq one = this.getOne(new QueryWrapper<Faq>().eq("type", up.getType()).eq("parent_id", up.getParentId()).eq("serial", up.getSerial() - 1));
                one.setSerial(one.getSerial() + 1);
                up.setSerial(up.getSerial() - 1);
                this.updateById(one);
                this.updateById(up);
                return RestResponse.ok(null, "1", "上移一位");
            } else {
                return RestResponse.ok(null, "0", "已经到顶了");
            }
        } else {
            return RestResponse.ok(null, "0", "此id不存在");
        }
    }

    public RestResponse down(int id) {
        Faq up = this.getById(id);
        if (up != null) {
            if (this.count(new QueryWrapper<Faq>().eq("type", up.getType()).eq("parent_id", up.getParentId()).eq("serial", up.getSerial())) > up.getSerial()) {
                Faq one = this.getOne(new QueryWrapper<Faq>().eq("type", up.getType()).eq("parent_id", up.getParentId()).eq("serial", up.getSerial() + 1));
                one.setSerial(one.getSerial() - 1);
                up.setSerial(one.getSerial() + 1);
                this.updateById(one);
                this.updateById(up);
                return RestResponse.ok(null, "1", "下移一位");
            } else {
                return RestResponse.ok(null, "0", "已经到顶了");
            }
        } else {
            return RestResponse.ok(null, "0", "此id不存在");
        }
    }
}