package cn.com.ty.lift.system.user.service.impl;

import cn.com.ty.lift.common.constants.ApiConstants;
import cn.com.ty.lift.system.user.dao.entity.UserAccount;
import cn.com.ty.lift.system.user.dao.entity.UserInfo;
import cn.com.ty.lift.system.user.dao.entity.model.UserRequest;
import cn.com.ty.lift.system.user.dao.entity.model.UserResponse;
import cn.com.ty.lift.system.user.service.IUserAccountService;
import cn.com.ty.lift.system.user.service.IUserInfoService;
import cn.com.ty.lift.system.user.service.IUserService;
import cn.com.ty.lift.system.utils.PasswordUtils;
import cn.com.xwy.boot.web.dto.RestResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Date;
import java.util.List;

/**
 * @author huangyuan
 * @date 2019-11-29
 * @description 用户接口
 */
@Service
public class UserService implements IUserService {

    @Autowired
    private IUserAccountService userAccountService;

    @Autowired
    private IUserInfoService userInfoService;

    @Override
    @Transactional
    public UserAccount saveUserInfo(UserRequest userRequest) {
        String password = userRequest.getPassword();
        UserAccount userAccount = new UserAccount();
        userAccount.setMobile(userRequest.getMobile());
        userAccount.setCreateDate(new Date());
        UserInfo userInfo = new UserInfo();
        userInfo.setName(userRequest.getName());

        //前端传递MD5加密密码，然后进行密码加密
        //1.生成16位随机码
        String salt = PasswordUtils.randomCode();
        //2.对密码进行加盐处理，并对加盐的密码进行哈希加密
        password = PasswordUtils.generatePassword(password, salt);
        userAccount.setSalt(salt);
        userAccount.setPassword(password);

        //保存用户账户
        int insertAccountCount = userAccountService.add(userAccount);
        //保存用户信息
        int insertInfoCount = userInfoService.add(userInfo);
        if(insertAccountCount == 0 || insertInfoCount == 0){
            return null;
        }
        return userAccount;
    }

    @Override
    public List<UserResponse> list(UserRequest userRequest) {
        UserAccount userAccount = new UserAccount(userRequest);
        List<UserAccount> userAccountList = userAccountService.getByUserAccount(userAccount);
        return null;
    }

    @Override
    public RestResponse addUser(UserRequest userRequest) {
        //保存用户信息，成功返回用户账户信息，失败返回空
        UserAccount userAccount = this.saveUserInfo(userRequest);
        if(userAccount == null){
            return RestResponse.error(ApiConstants.RESULT_ERROR, "新增用户失败");
        }
        return RestResponse.ok(userAccount, ApiConstants.RESULT_SUCCESS, "新增用户成功");
    }

    @Override
    @Transactional
    public RestResponse updateUser(UserRequest userRequest) {
        UserAccount userAccount = userAccountService.getByUserId(userRequest.getUserId());
        UserInfo userInfo = userInfoService.getByUserId(userRequest.getUserId());
        userAccount.setMobile(userRequest.getMobile());
        userInfo.setName(userRequest.getName());
        int updateAccount = userAccountService.update(userAccount);
        int updateInfo = userInfoService.update(userInfo);
        if(updateAccount == 0 || updateInfo == 0){
            return RestResponse.error(ApiConstants.RESULT_ERROR, "更新用户信息失败");
        }
        return RestResponse.ok(null, ApiConstants.RESULT_SUCCESS, "更新用户信息成功");
    }

    @Override
    @Transactional
    public RestResponse deleteUser(UserRequest userRequest) {
        return null;
    }

    @Override
    public RestResponse assignRole(UserRequest userRequest) {
        return null;
    }
}
