package cn.com.ty.lift.system.user.tree;

import cn.com.ty.lift.system.utils.ProjectUtils;

import java.util.List;
import java.util.Map;

/**
 * @author huangyuan
 * @date 2019-12-02
 * @description 树工具类
 */
public class TreeUtil {
    /**
     * 将包含所有对象的集合转化为树结构
     *
     * @param treeList
     * @param parentAttr
     * @param rootParentId
     * @return List<? extends BaseTree>
     * @throws
     * @author huangy
     */
    public static <T> List listToTree(List treeList, String parentAttr, T rootParentId) {
        BaseTree rootBaseTree = new BaseTree();
        Map parentIdToChild = ProjectUtils.attrToListMap(treeList, parentAttr, null);
        getChildren(rootBaseTree, parentIdToChild, rootParentId);
        return rootBaseTree.getChildren();
    }

    /**
     * 递归设置子集合
     *
     * @param baseTree
     * @param parentIdToChild
     * @param rootParentId    根节点父id
     * @throws
     * @author huangy
     */
    private static <T> void getChildren(BaseTree baseTree, Map<? extends Object, List<? extends BaseTree>> parentIdToChild, T rootParentId) {
        List<? extends BaseTree> children = parentIdToChild.get(rootParentId);
        if (children != null && children.size() > 0) {
            for (BaseTree baseTreeInfo : children) {
                //info:递归设置子集合
                getChildren(baseTreeInfo, parentIdToChild, baseTreeInfo.getId());
            }
        }
        //info:设置子集合
        baseTree.setChildren(children);
    }
}
